@@ -12,7 +12,7 @@ BEGIN {
   $Dist::Zilla::Plugin::NoSmartCommentsTests::AUTHORITY = 'cpan:RSRCHBOY';
 }
 BEGIN {
-  $Dist::Zilla::Plugin::NoSmartCommentsTests::VERSION = '0.005';
+  $Dist::Zilla::Plugin::NoSmartCommentsTests::VERSION = '0.006';
 }
 
 # ABSTRACT: Make sure no Smart::Comments escape into the wild
@@ -36,13 +36,13 @@ Dist::Zilla::Plugin::NoSmartCommentsTests - Make sure no Smart::Comments escape
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
 In C<dist.ini>:
 
-    [NoSmartCommentTests]
+    [NoSmartCommentsTests]
 
 =head1 DESCRIPTION
 
@@ -51,6 +51,29 @@ following file:
 
   xt/release/no-smart-comments.t - test to ensure no Smart::Comments
 
+=head1 NOTE
+
+The name of this plugin has turned out to be somewhat misleading, I'm afraid:
+we don't actually test for the _existance_ of smart comments, rather we
+ensure that Smart::Comment is not used by any file checked.
+
+=head1 SEE ALSO
+
+L<Smart::Comments>, L<Test::NoSmartComments>
+
+=head1 BUGS
+
+All complex software has bugs lurking in it, and this module is no exception.
+
+Please report any bugs to
+"bug-dist-zilla-plugin-nosmartcommentstests@rt.cpan.org", or through the web
+interface at <http://rt.cpan.org>.
+
+Patches and pull requests through GitHub are most welcome; our page and repo
+(same URI):
+
+    https://github.com/RsrchBoy/dist-zilla-plugin-nosmartcommentstests
+
 =head1 AUTHOR
 
 Chris Weyl <cweyl@alumni.drew.edu>
